pub struct InvocationHandle { /* private fields */ }Expand description
A handle to an invocation.
You can obtain an InvocationHandle in three ways:
- From
ContextClient::invocation_handle, when you already know the invocation id. - By
.await-ing theSendHandlereturned byRequest::send/Request::send_after. - By
.await-ingCallFuture::invocation_handle.
Once obtained, the invocation id is known synchronously via InvocationHandle::invocation_id.
Implementations
Sourceimpl InvocationHandle
impl InvocationHandle
Sourcepub fn invocation_id(&self) -> &str
pub fn invocation_id(&self) -> &str
The invocation id of the target invocation.
Sourcepub fn attach<T: Deserialize + 'static>(
&self,
) -> impl DurableFuture<Output = Result<T, TerminalError>> + Send + use<T>
pub fn attach<T: Deserialize + 'static>( &self, ) -> impl DurableFuture<Output = Result<T, TerminalError>> + Send + use<T>
Attach to the invocation, returning a future that resolves with its output/result.