pub struct SignalHandle { /* private fields */ }Expand description
A handle to a named signal on a target invocation, obtained via InvocationHandle::signal.
Use it to complete a signal the target invocation is (or will be) awaiting via
ContextSignals::signal.
Implementations
Sourceimpl SignalHandle
impl SignalHandle